@@ -1,4 +1,4 @@
-package MPMinus::Helper::Handlers; # $Id: Handlers.pm 209 2013-07-26 12:19:28Z minus $
+package MPMinus::Helper::Handlers; # $Id: Handlers.pm 224 2017-04-04 10:27:41Z minus $
 use strict;
 
 =head1 NAME
@@ -7,7 +7,7 @@ MPMinus::Helper::Handlers - MPMinus helper's handlers
 
 =head1 VERSION
 
-Version 1.05
+Version 1.06
 
 =head1 SYNOPSIS
 
@@ -21,11 +21,11 @@ See mpm manpage
 
 =head1 AUTHOR
 
-Serz Minus (Lepenkov Sergey) L<http://serzik.ru> E<lt>minus@mail333.comE<gt>
+Sergey Lepenkov (Serz Minus) L<http://www.serzik.com> E<lt>minus@serzik.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2013 D&D Corporation. All Rights Reserved
+Copyright (C) 1998-2017 D&D Corporation. All Rights Reserved
 
 =head1 LICENSE
 
@@ -44,7 +44,7 @@ See C<LICENSE> file
 =cut
 
 use vars qw($VERSION);
-$VERSION = 1.04;
+$VERSION = 1.06;
 
 use constant {
         NOTCONFIGURED => "MPMinus is not configured! Please type following command:\n\n\tmpm config",
@@ -240,10 +240,18 @@ sub TEST {
     # 1.  httpd,     
     $tst = "HTTPD values";
     start _ sprintf('%d/%d %s',++$i,$steps, $tst);
-    my $apache = getApache($c);
-    my ($aroot, $aconfig) = ($apache->{HTTPD_ROOT},$apache->{SERVER_CONFIG_FILE});
-    $tbl->row('HTTPD root directory', $aroot, ($aroot && (-e $aroot) && ((-d $aroot) || (-l $aroot))) ? 'PASSED' : 'FAILED');
-    $tbl->row('HTTPD server config file', $aconfig, ($aconfig && (-e $aconfig) && ((-f $aconfig) || (-l $aconfig))) ? 'PASSED' : 'FAILED');
+    my $apache = getApache();
+    my ($aroot, $aconfig, $sver, $aver) = (
+            $apache->{HTTPD_ROOT},
+            $apache->{SERVER_CONFIG_FILE},
+            $apache->{SERVER_VERSION},
+            $apache->{APACHE_VERSION},
+        );
+    $tbl->row('HTTPD Root Directory', $aroot, ($aroot && (-e $aroot) && ((-d $aroot) || (-l $aroot))) ? 'PASSED' : 'FAILED');
+    $tbl->row('HTTPD Server Config File', $aconfig, ($aconfig && (-e $aconfig) && ((-f $aconfig) || (-l $aconfig))) ? 'PASSED' : 'FAILED');
+    $tbl->row('HTTPD Server Version', $sver, ($sver) ? 'PASSED' : 'FAILED');
+    $tbl->row('HTTPD Apache Version', $aver, ($aver && $aver > 2) ? 'PASSED' : 'FAILED');
+    
     finish "DONE";
     
     # 2. ModPerlRoot
