@@ -1,4 +1,4 @@
-package MPMinus::Helper::Util; # $Id: Util.pm 197 2013-07-23 14:04:29Z minus $
+package MPMinus::Helper::Util; # $Id: Util.pm 224 2017-04-04 10:27:41Z minus $
 use strict;
 
 =head1 NAME
@@ -7,7 +7,7 @@ MPMinus::Helper::Util - MPMinus Helper's utility
 
 =head1 VERSION
 
-Version 1.02
+Version 1.03
 
 =head1 SYNOPSIS
 
@@ -39,11 +39,12 @@ Returns clean name of server
 
 Returns clean name of server as file
 
-=item B<getApache>
+=item B<getApache>, B<getApache2>
 
-    my $hash = getApache( $c );
+    my $hash = getApache();
 
-Returns HTTPD_ROOT and SERVER_CONFIG_FILE as hash reference
+Returns HTTPD_ROOT, SERVER_CONFIG_FILE, SERVER_VERSION and APACHE_VERSION as hash structure
+(reference).
 
 =item B<newconfig>
 
@@ -61,11 +62,11 @@ Returns '' (void) if undefined $value else - returns $value
 
 =head1 AUTHOR
 
-Serz Minus (Lepenkov Sergey) L<http://serzik.ru> E<lt>minus@mail333.comE<gt>
+Sergey Lepenkov (Serz Minus) L<http://www.serzik.com> E<lt>minus@serzik.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2013 D&D Corporation. All Rights Reserved
+Copyright (C) 1998-2017 D&D Corporation. All Rights Reserved
 
 =head1 LICENSE
 
@@ -84,11 +85,11 @@ See C<LICENSE> file
 =cut
 
 use vars qw($VERSION);
-$VERSION = 1.02;
+$VERSION = 1.03;
 
 use base qw /Exporter/;
 our @EXPORT = qw(
-        getApache
+        getApache getApache2
         newconfig
         to_void
         cleanProjectName
@@ -96,17 +97,15 @@ our @EXPORT = qw(
         cleanServerNameF
     );
 
-use CTK::Util;
+use CTK::Util qw/ :ALL /;
 use CTK::ConfGenUtil;
 use Try::Tiny;
 
-sub getApache {
-    #   (HTTP_ROOT, SERVER_CONFIG_FILE)     APACHE
-    my $c = shift;
-    
+sub getApache2 {
+    #   (HTTP_ROOT, SERVER_CONFIG_FILE, SERVER_VERSION, APACHE_VERSION)     APACHE
     my $httpdata;
     my $httpdpath;
-    if ($c->isostype("Windows")) {
+    if (isostype("Windows")) {
         $httpdpath = execute(q{pv.exe -e 2>NUL});
         if ($httpdpath =~ /^httpd.exe\s+\d+\s+\S+\s+(.+?)\s*$/m) {
             $httpdpath = $1;
@@ -122,16 +121,31 @@ sub getApache {
         }
     } else {
         # Fix #198
-        foreach my $httpd (qw/httpd apache apache2 apache22/) {
-            try { $httpdata = execute(qq{$httpd -V}) } catch { carp($_) };
+        my @err;
+        foreach my $httpd (qw/httpd apache apachectl apache2ctl apache2 apache22/) {
+            my $cmd = qq{$httpd -V};
+            try {
+                $httpdata = execute($cmd)
+            } catch {
+                push @err, sprintf("%s: %s", $cmd, $_)
+            };
             last if $httpdata && $httpdata =~ /HTTPD_ROOT/im;
         }
+        carp(join "\n", @err) if (!$httpdata) && @err
     }
-    #return $httpdata;
-
-    #   
+    
     my $httpd_root          = $httpdata =~ /HTTPD_ROOT\="(.+?)"/m ? $1 : '';
     my $server_config_file  = $httpdata =~ /SERVER_CONFIG_FILE\="(.+?)"/m ? $1 : '';
+    my $sver                = $httpdata =~ /version\:\s+[a-z]+\/([0-9.]+)/im ? $1 : '';
+    my $aver                = 0;
+    
+    if ($sver =~ /([0-9]+)\.([0-9]+)\.([0-9]+)/) {
+        $aver = $1 + ($2/100) + ($3/10000);
+    } elsif ($sver =~ /([0-9]+)\.([0-9]+)/) {
+        $aver = $1 + ($2/100);
+    } elsif ($sver =~ /([0-9]+)/) {
+        $aver = $1;
+    }
     
     my $httpdconfig = '';
     if ($server_config_file && $httpd_root) {
@@ -140,16 +154,12 @@ sub getApache {
     
     my $acc = '';
     unless ($httpdconfig && -e $httpdconfig) {
-        #   -   
         foreach (split /[\/\\]/, $httpdpath) {
             $acc = $acc ? catfile($acc,$_) : $_;
             
             $httpdconfig = catfile($acc,$server_config_file);
             if ($httpdconfig && (-e $httpdconfig) && ((-f $httpdconfig) || (-l $httpdconfig))) {
-                #::debug(" -- \"$httpdconfig\" [OK]");
                 last;
-            } else {
-                #::debug(" -- \"$httpdconfig\" [SKIP]");
             }
         }
     }
@@ -157,9 +167,12 @@ sub getApache {
     return {
             HTTPD_ROOT          => $acc || $httpd_root, 
             SERVER_CONFIG_FILE  => $httpdconfig || '',
+            SERVER_VERSION      => $sver,
+            APACHE_VERSION      => $aver,
         };
 
 }
+sub getApache { goto &getApache2 }
 sub newconfig {
     #   
     my $c = shift;
@@ -170,7 +183,7 @@ sub newconfig {
         );
 
     my ($k,$v,$d) = ('','','');
-    my $apache = getApache($c);
+    my $apache = getApache();
 
     # Apache HTTPD_ROOT
     $k = "HttpdRoot";
