@@ -1,4 +1,4 @@
-package MPMinus::Transaction; # $Id: Transaction.pm 151 2013-05-29 14:31:19Z minus $
+package MPMinus::Transaction; # $Id: Transaction.pm 218 2013-10-01 15:22:22Z minus $
 use strict;
 
 =head1 NAME
@@ -7,7 +7,7 @@ MPMinus::Transaction - MVC SKEL transaction
 
 =head1 VERSION
 
-Version 1.04
+Version 1.05
 
 =head1 SYNOPSIS
 
@@ -85,10 +85,36 @@ See C<LICENSE> file
 =cut
 
 use vars qw($VERSION);
-$VERSION = 1.04;
+$VERSION = 1.05;
 
+use Apache2::Const;
 use CTK::Util qw/ :API /;
 
+use constant {
+        HOOKS => { # Returned values of hooks / Types of hooks
+                caccess => {
+                        aliases => [qw/caccess access/],
+                        type    => 'DUAL', # BOOL and HTTP way
+                    },
+                cdeny   => {
+                        aliases => [qw/cdeny deny/],
+                        type    => 'HTTP', # Analyzing common constants and HTTP 1.1 status codes
+                    },
+                cchck   => {
+                        aliases => [qw/cchck chck check/],
+                        type    => 'BOOL', # 0 - false / !0 - true
+                    },
+                mproc   => {
+                        aliases => [qw/mproc proc proccess/],
+                        type    => 'HTTP', # Analyzing common constants and HTTP 1.1 status codes
+                    },
+                vform   => {
+                        aliases => [qw/vform form/],
+                        type    => 'HTTP', # Analyzing common constants and HTTP 1.1 status codes
+                    },
+            },
+    };
+
 sub ActionTransaction {
     #   (  )
     my $m = shift || '';
@@ -107,7 +133,7 @@ sub ActionTransaction {
         $sts = ActionExecute($m,$key,'cdeny');
         return $sts;
     }
-    return $sts if $sts >= 300; #    300  
+    return $sts if $sts >= 300; #    300   (  caccess)
       
     #          () 
     $sts = ActionExecute($m,$key,'mproc') if (($event =~ /go/i) && ActionExecute($m,$key,'cchck'));
@@ -121,35 +147,54 @@ sub ActionExecute {
     #         0- (false)  
     my $m = shift || '';
     my $key = shift || return 0;
-    my $typ = shift || return 0;
+    my $hook = shift || return 0;
     my @params = @_;
     croak("The method call is made ActionExecute not in the style of OOP") unless ref($m) =~ /MPMinus/;
 
     return 0 unless ActionCheck($m,$key); #    -- 
-    return 0 unless grep {$_ eq $typ} qw/mproc vform cchck caccess cdeny/;
+    my %hooks = %{(HOOKS)};
+    return 0 unless grep {$_ eq $hook} keys %hooks; #  0       (default)
 
-    #  
+    #    .mpm
     my $grec = $m->drec;
     my $rec = $grec->{actions}{$key}{handler};
+    my $phase = _getPhaseByAlias($rec,$hook);
+    
+    #$m->debug("> Running $hook");
     
     #no strict 'refs'; #        
-    if (ref($rec->{$typ}) eq 'CODE') {
+    if (ref($phase) eq 'CODE') {
         #  
-        return $rec->{$typ}->($m,@params)
-    } elsif (ref($rec->{$typ}) eq 'ARRAY') {
+        #$m->debug("> -- $hook -> CODE");
+        return $phase->($m,@params)
+    } elsif (ref($phase) eq 'ARRAY') {
         #      
         my $status;
-        my @codes = @{$rec->{$typ}}; #    
-        foreach (@codes) {
+        foreach (@$phase) {
             # $m->debug($_->($m,@params));
             $status = (ref($_) eq 'CODE') ? $_->($m,@params) : 0;
-            last unless $status; #    -   false
+            #$m->debug("> $hook -> CODE[$status]");
+            my $typ = $hooks{$hook}{type};
+            
+            if ($typ eq 'BOOL') {
+                last unless $status; #    -   false
+            } elsif ($typ eq 'HTTP') {
+                #    >=300 (REDIRECTIONS AND ERRORS)
+                last unless (($status =~ /^[+\-]?\d+$/) && $status < 300);
+            } elsif ($typ eq 'DUAL') {
+                last unless $status; #    -   false
+                #    0 (OK)  >=300 (REDIRECTIONS AND ERRORS)
+                last unless (($status =~ /^[+\-]?\d+$/) && $status < 300);
+            } else { # VOID and etc.
+                $status = Apache2::Const::OK;
+            }
         }
-        #$m->debug(join(", ",@{$rec->{$typ}}));
         return $status;
     } else {
-        return 0
+        #$m->debug("> -- $hook -> VOID");
+        return 0;
     }
+    return 0;
 }
 sub ActionCheck {
     my $m = shift || '';
@@ -168,4 +213,20 @@ sub getActionRecord {
     }
     return $grec->{actions};
 }
+sub _getPhaseByAlias {
+    my $rec = shift || {};
+    my $hook = shift || '_';
+    my %hooks = %{(HOOKS)};
+    my $aliases = $hooks{$hook}{aliases};
+    
+    my $ret;
+    foreach (@$aliases) {
+        if ($rec->{$_} && ref($rec->{$_})) {
+            $ret = $rec->{$_};
+            last;
+        }
+    }
+    
+    return $ret;
+}
 1;
